MyUtilityExtensionDateTimeIsAtSameDayAs extension
- on
Methods
-
isAtSameDayAs(
DateTime other) → bool -
Available on DateTime, provided by the MyUtilityExtensionDateTimeIsAtSameDayAs extension
Returns true ifotheris on the same day as this.
Available on DateTime, provided by the MyUtilityExtensionDateTimeIsAtSameDayAs extension
Returns true ifother is on the same day as this.