startOfDay property
DateTime
get
startOfDay
Get a new DateTime with the same year, month and day, but the time is set to the first microsecond when day started.
See also MyUtilityExtensionDateTimeEndOfDay.
Implementation
DateTime get startOfDay => copyWith(
hour: 0,
minute: 0,
second: 0,
millisecond: 0,
microsecond: 0,
);