range library
Classes
-
ComparableRange<
T extends Comparable< T> > - Represents a range of Comparable values such as String or DateTime
- DoubleRange
- IntProgression
- IntRange
- A iterable range between two ints which is iterable with a specific step size
-
Range<
T extends Comparable> - Represents a range of values (for example, numbers or characters) with a fixed start value and a fixed endInclusive value.
Extensions
- MyUtilityExtensionComparableRangeTo on T
- MyUtilityExtensionDoubleRangeTo on double
-
Special variant for double which implements
Comparable<num>and therefore doesn't work for theComparable<T>.rangeTo(T)extension - MyUtilityExtensionIntRangeTo on int
- The equivalent for double is MyUtilityExtensionDoubleRangeTo